==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/ASPECTUOMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour ASPECTUOMID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASPECTUOMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTUOMID_Type", propOrder = {
    "aspectid",
    "uomid"
})
public class ASPECTUOMID_Type {

    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;

    /**
     * Obtient la valeur de la propriété aspectid.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Définit la valeur de la propriété aspectid.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

    /**
     * Obtient la valeur de la propriété uomid.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Définit la valeur de la propriété uomid.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/ASPECTUOMID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ASPECTUOMID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASPECTUOMID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASPECTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UOMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASPECTUOMID_Type", propOrder = {
    "aspectid",
    "uomid"
})
public class ASPECTUOMID_Type {

    @XmlElement(name = "ASPECTID", required = true)
    protected ASPECTID_Type aspectid;
    @XmlElement(name = "UOMID", required = true)
    protected UOMID_Type uomid;

    /**
     * Gets the value of the aspectid property.
     * 
     * @return
     *     possible object is
     *     {@link ASPECTID_Type }
     *     
     */
    public ASPECTID_Type getASPECTID() {
        return aspectid;
    }

    /**
     * Sets the value of the aspectid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASPECTID_Type }
     *     
     */
    public void setASPECTID(ASPECTID_Type value) {
        this.aspectid = value;
    }

    /**
     * Gets the value of the uomid property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getUOMID() {
        return uomid;
    }

    /**
     * Sets the value of the uomid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setUOMID(UOMID_Type value) {
        this.uomid = value;
    }

}
